<?php
/**
*
* search_ignore_words [Português]
*
* @package language
* @version 1.0.4
* @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
* 
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$words = array(
   'um', 
   'sobre', 
   'depois', 
   'antes', 
   'todos', 
   'quase', 
   'além', 
   'bastante', 
   'além disso', 
   'sou', 
   'um', 
   'e', 
   'resposta', 
   'qualquer', 
   'qualquer pessoa', 
   'qualquer pessoas', 
   'qualquer lugar', 
   'só', 
   'não só', 
   'em volta', 
   'como', 
   'perguntar', 
   'indagar', 
   'em', 
   'mal', 
   'ser', 
   'porque', 
   'sido, estado', 
   'antes', 
   'existência', 
   'melhor', 
   'melhor', 
   'entre', 
   'grande', 
   'btw', 
   'mas', 
   'por', 
   'poder', 
   'não poder', 
   'surgir', 
   'pôde', 
   'não pôde', 
   'dia', 
   'dias', 
   'dias de', 
   'eis', 
   'não fui', 
   'faz', 
   'fez', 
   'não fez', 
   'não faz', 
   'abaixo', 
   'cada', 
   'etc', 
   'ambos', 
   'outro', 
   'igual', 
   'sempre', 
   'tudo', 
   'todos os', 
   'todas as', 
   'todos estes', 
   'distância', 
   'pesquisar', 
   'por', 
   'encontrado', 
   'de', 
   'receber', 
   'ir', 
   'indo', 
   'ido', 
   'bom', 
   'recebeu', 
   'recebido', 
   'tido', 
   'tem', 
   'ter', 
   'não tem', 
   'tendo', 
   'ela', 
   'aqui', 
   'ela', 
   'ele', 
   'ele', 
   'casa', 
   'como', 
   'como', 
   'href', 
   'Eu', 
   'Eu gostaria', 
   'se', 
   'não', 
   'ini', 
   'dentro', 
   'é', 
   'não é', 
   'isto', 
   'isto é', 
   'isto não é', 
   'exato', 
   'saber', 
   'largo', 
   'menos', 
   'gostar', 
   'gostou', 
   'pequeno', 
   'olhando', 
   'olhar', 
   'observado', 
   'observando', 
   'muito', 
   'talvez', 
   'muito', 
   'eu', 
   'mais', 
   'maior parte', 
   'muito', 
   'obrigação', 
   'sem obrigação', 
   'meu', 
   'perto', 
   'precisar', 
   'nunca', 
   'novidade', 
   'novidades', 
   'não', 
   'nenhum', 
   'nem', 
   'nada', 
   'agora', 
   'de', 
   'desligar', 
   'frequência', 
   'velho', 
   'ligar', 
   'uma vez', 
   'apenas', 
   'oops', 
   'ou', 
   'outro', 
   'nosso', 
   'nossos', 
   'fora', 
   'acima', 
   'página', 
   'por favor', 
   'colocar', 
   'pergunta', 
   'perguntas', 
   'perguntado', 
   'citação', 
   'um tanto', 
   'realmente', 
   'recente', 
   'disse', 
   'visualizou', 
   'dizer', 
   'disse', 
   'ela', 
   'ver', 
   'vê', 
   'recomendar', 
   'sites', 
   'pequeno', 
   'então', 
   'algum', 
   'alguma coisa', 
   'alguma hora', 
   'algum lugar', 
   'logo', 
   'pegar', 
   'que', 
   'verdade', 
   'agradecer', 
   'que ', 
   'que gostaria', 
   'que está', 
   'o', 
   'dele', 
   'deles', 
   'lá, lá está', 
   'deles, delas', 
   'os, as, lhes', 
   'então', 
   'l', 
   'estes, estas', 
   'eles', 
   'eles irão', 
   'eles gostariam', 
   'eles só, estão', 
   'este, esta', 
   'esses, essas', 
   'ideia', 
   'completo', 
   'deste modo', 
   'vez', 
   'vezes', 
   'para', 
   'também', 
   'abaixo', 
   'até', 
   'incorreto', 
   'acima', 
   'acima de', 
   'utilizar', 
   'Utilizadores', 
   'versão', 
   'muito', 
   'por', 
   'desejar', 
   'não foi, não estava', 
   'maneira', 
   'nós', 
   'bem', 
   'fui', 
   'era, estava', 
   'não era, não estava', 
   'o que, qual', 
   'quando', 
   'onde', 
   'que', 
   'quem', 
   'o qual, a qual', 
   'cujo, cuja', 
   'porque', 
   'extenso', 
   'ir', 
   'com', 
   'com', 
   'sem', 
   'no ir', 
   'mundo', 
   'inferior', 
   'pior', 
   'seria, iria', 
   'escrito', 
   'www', 
   'sim', 
   'ainda', 
   'você', 
   'você seria, iria', 
   'você ir', 
   'seu', 
   'você é', 
   'seus', 
   'AFAIK', 
   'IIRC', 
   'LOL', 
   'ROTF', 
   'ROTFLMAO', 
   'YMMV', 
); 

?>